@@ -12,7 +12,7 @@ is $^H{"Lexical::SealRequireHints/test"}, undef;
 
 sub import {
 	is $^H{"Lexical::SealRequireHints/test"}, 1;
-	$^H |= 0x20000 if $] < 5.009004;
+	$^H |= 0x20000 if "$]" < 5.009004;
 	$^H{"Lexical::SealRequireHints/test0"}++;
 }
 
